// Importing required functions from d3 library
import { select, json, geoPath, geoTransverseMercator, zoom, event } from "d3"; // Importing necessary D3 modules
import { feature } from "topojson";
const svg = select("svg"); // Select the svg element in HTML

const width = +svg.attr('width'); // Get width of SVG element and convert to number
const height = +svg.attr('height'); // Get height of SVG element and convert to number

const projection = d3.geoTransverseMercator() // Define a Transverse Mercator projection
  .center([2.5, -38.5]) // Set the center of the projection
  .rotate([66, 0]) // Set the rotation of the projection
  .scale((height * 54) / 33) // Set the scale of the projection
  .translate([(width / 2), (height / 2)]); // Set the translation of the projection
const pathGenerator = geoPath().projection(projection); // Create a path generator using the projection

const g = svg.append('g') // Append a group element to the SVG

g.append('path') // Append a path element to the group for the sphere
  .attr('class', 'sphere') // Set the class to 'sphere'
  .attr('d', pathGenerator({type: 'Sphere'})); // Set the d attribute of the path using the path generator

svg.call(zoom().on('zoom', () => { // Add zoom behavior to the SVG element
  g.attr('transform', event.transform) // Transform the group according to the current zoom level
}));

json('https://raw.githubusercontent.com/mgaitan/departamentos_argentina/master/departamentos-argentina.json') // Load the JSON data file
  .then(data => {
    g.selectAll('#path') // Select all path elements in the group (although there are none at this point)
      .data(data.features) // Bind the JSON data to the selection
      .enter().append('path') // Append a path element for each data feature
				.attr('class', 'country') // Set the class to 'country'
				.attr('d', pathGenerator) // Set the d attribute of the path using the path generator
  		.append('title') // Append a title element to the path
  			.text(d => d.properties.departamento +', '+ d.properties.provincia); // Set the text of the title to the department and province properties of the feature
  });
